Index: classdef.cpp
===================================================================
--- classdef.cpp	(revision 626)
+++ classdef.cpp	(working copy)
@@ -1029,7 +1029,8 @@
     // write class diagram using dot
   {
     DotClassGraph inheritanceGraph(this,DotNode::Inheritance);
-    if (!inheritanceGraph.isTrivial() && !inheritanceGraph.isTooBig())
+    if ((Config_getBool("SHOW_TRIVIAL_GRAPHS") || !inheritanceGraph.isTrivial()) 
+        && !inheritanceGraph.isTooBig())
     {
       ol.pushGeneratorState();
       ol.disable(OutputGenerator::Man);
@@ -1155,7 +1156,7 @@
   if (Config_getBool("HAVE_DOT") && Config_getBool("COLLABORATION_GRAPH"))
   {
     DotClassGraph usageImplGraph(this,DotNode::Collaboration);
-    if (!usageImplGraph.isTrivial())
+    if (Config_getBool("SHOW_TRIVIAL_GRAPHS") || !usageImplGraph.isTrivial())
     {
       ol.pushGeneratorState();
       ol.disable(OutputGenerator::Man);
Index: config.l
===================================================================
--- config.l	(revision 626)
+++ config.l	(working copy)
@@ -2968,6 +2968,25 @@
                  );
   cb->addDependency("HAVE_DOT");
   cb = addBool(
+                    "SHOW_TRIVIAL_GRAPHS",
+                    "If one of the graph options are selected, and HAVE_DOT is set to YES, \n"
+                    "then doxygen will generate that particular graph.  However, if that graph \n"
+                    "is considered 'trivial' (with no connections to other nodes) then it will \n"
+                    "not be drawn. Setting this flag to YES will supercede that logic, and force \n"
+                    "trivial graphs to be drawn. \n",
+                    FALSE
+                 );
+  cb->addDependency("HAVE_DOT");
+  cb = addBool(
+                    "VERBOSE_GRAPH_DATA",
+                    "If one of the graph options are selected, and HAVE_DOT is set to YES, \n"
+                    "then doxygen will generate that particular graph.  By setting this option to \n"
+                    "YES, then doxygen will generate extended information for members in the graph \n"
+                    "including return type/variable type, as well as function parameters \n",
+                    FALSE
+                 );
+  cb->addDependency("HAVE_DOT");
+  cb = addBool(
                     "COLLABORATION_GRAPH",
                     "If the COLLABORATION_GRAPH and HAVE_DOT tags are set to YES then doxygen \n"
                     "will generate a graph for each documented class showing the direct and \n"
Index: dot.cpp
===================================================================
--- dot.cpp	(revision 626)
+++ dot.cpp	(working copy)
@@ -575,8 +575,20 @@
     {
       if (mma->getClassDef() == scope)
       {
-        t << prot << " " << convertLabel(mma->name());
-        if (!mma->isObjCMethod() && mma->isFunction()) t << "()";
+        t << prot << " ";
+        if(Config_getBool("VERBOSE_GRAPH_DATA"))
+        {
+            // Display the type/return type, name, and arguments
+            t << convertLabel(mma->typeString()) << " ";
+            t << convertLabel(mma->name());
+            if (!mma->isObjCMethod() && mma->isFunction()) t << convertLabel(mma->argsString());
+        }
+        else
+        {
+            // Display the name, and no arguments
+            t << convertLabel(mma->name());
+            if (!mma->isObjCMethod() && mma->isFunction()) t << "()";
+        }
         t << "\\l";
       }
     }
